@@ -11,11 +11,24 @@ using a Metropolis-Hastings Monte Carlo algorithm
  Copyright 2001-2003 Peter Beerli and Joseph Felsenstein
  Copyright 2004-2005 Peter Beerli
 
- This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: gammalike.c 1800 2011-01-29 13:40:00Z beerli $
+$Id: gammalike.c 2120 2013-01-03 05:17:21Z beerli $
 */
 /*! \file gammalike.c 
 
@@ -55,13 +68,14 @@ gamma_loci_like(helper_fmt *helper, MYREAL *oparam, MYREAL *olparam, MYREAL deno
     long locus;
     MYREAL summ = 0.0;
     nr_fmt *nr = helper->nr;
+    MYREAL *locusweight = helper->nr->world->data->locusweight; //invariant loci treatment
     for (locus = 0; locus < nr->world->loci; locus++)
     {
         if (nr->skiploci[locus])
             continue;
         nr->locilikes[locus] =
             gamma_locus_like (nr, oparam, olparam, denom, locus);
-        summ += nr->locilikes[locus];
+        summ += locusweight[locus] * nr->locilikes[locus];
     }
     return summ;
 }
@@ -206,6 +220,7 @@ MYREAL find_gamma_summ(MYREAL lla, MYREAL theta1, nr_fmt *nr, MYREAL *oparam, MY
     MYREAL summ=0.0;
     MYREAL so = oparam[nr->numpop2];
     MYREAL slo = olparam[nr->numpop2];
+    MYREAL *locusweight = helper->nr->world->data->locusweight; //invariant loci treatment
     oparam[nr->numpop2] = la;
     olparam[nr->numpop2] = lla;
     if (olparam[nr->numpop2] > 9.903487553)
@@ -220,7 +235,7 @@ MYREAL find_gamma_summ(MYREAL lla, MYREAL theta1, nr_fmt *nr, MYREAL *oparam, MY
         if (nr->skiploci[locus])
             continue;
         nr->locilikes[locus] = gamma_locus_like (nr, oparam, olparam, denom, locus);
-        summ += nr->locilikes[locus];
+        summ += locusweight[locus] * nr->locilikes[locus]; //invariant loci treatment
     }
     oparam[nr->numpop2] = so;
     olparam[nr->numpop2] = slo;
@@ -407,7 +422,7 @@ gamma_locus_derivative (helper_fmt * helper, long locus)
             if (i == nr->numpop2)
             {
                 sumi = sumi *(EXP (tempmax[i] - nr->locilikes[locus]))
-                       - polygamma (0, alpha) - LOG (theta1 / alpha) +1.;
+                       - polygamma (0L, alpha) - LOG (theta1 / alpha) +1.;
             }
             else
                 sumi = sumi * EXP (tempmax[i] - nr->locilikes[locus]);
