@@ -11,12 +11,27 @@
  
  Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
+
+ Permission is hereby granted, free of charge, to any person obtaining
+ a copy of this software and associated documentation files (the
+ "Software"), to deal in the Software without restriction, including
+ without limitation the rights to use, copy, modify, merge, publish,
+ distribute, sublicense, and/or sell copies of the Software, and to
+ permit persons to whom the Software is furnished to do so, subject
+ to the following conditions:
  
- This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
+ The above copyright notice and this permission notice shall be
+ included in all copies or substantial portions of the Software.
  
-$Id: lrt.c 2056 2012-06-14 02:38:30Z beerli $
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
+ ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
+ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ 
+$Id: lrt.c 2158 2013-04-29 01:56:20Z beerli $
  
 -------------------------------------------------------*/
 /* \file lrt.c 
